library(ggplot2)
library(foreign)

kfa <- read.spss("U:/Eigene Dateien/R/kfa.sav", to.data.frame = TRUE, reencode="utf-8")

# Mittelwerte einer metrischen AV fr die Ausgrgungen einer kategorialen UV
ggplot(kfa,aes(x=geschl,y=aergo)) + geom_line(stat="summary",fun.y=mean, aes(group=1)) + geom_point(stat="summary",fun.y=mean)

# Messwiederholungsdesign, Verbindungslinie fr die Mittelwerte, Fehlerbalken
library(reshape2)
kfa.long <- melt(kfa, id.vars = c("fnr","geschl"), measure.vars = c("aergo","aergm"), variable.name = "kfa")
kfa.long$kfa <- factor(kfa.long$kfa, labels=c("Ohne","Mit"))
kfa.long$fnr <- factor(kfa.long$fnr)
ggplot(kfa.long,aes(x=kfa,y=value)) +
  geom_point(stat="summary",fun.y=mean, size=5) +
  geom_line(stat="summary", fun.y=mean, aes(group=1), size=1) +
  geom_errorbar(stat="summary", fun.data=mean_cl_normal, width=0.5, size=1,colour="gray50") +
  labs(x="KFA", y="Mittlerer rger\n")

# Messwiederholungsdesign, Spaghetti-Plot
ggplot(kfa.long, aes(x=kfa,y=value,colour=fnr)) +
  geom_point(show_guide=FALSE) +  geom_line(aes(group=fnr), show_guide=FALSE) +
  labs(x="KFA", y="Mittlerer rger\n")

# Spaghetti-Plot plus Mittelwerte mit Fehlerbalken
ggplot(kfa.long, aes(x=kfa,y=value,colour=fnr)) +
  geom_point(show_guide=FALSE) +  geom_line(aes(group=fnr), show_guide=FALSE) +
  geom_point(stat="summary",fun.y=mean, show_guide=FALSE) +
  geom_line(stat="summary", fun.y=mean, aes(group=1), size=1, show_guide=FALSE) +
  geom_errorbar(stat="summary", fun.data=mean_cl_normal, width=0.3, size=1,colour="gray50") +
  labs(x="KFA", y="Mittlerer rger\n")

